@@ -259,14 +259,6 @@ class SagemakerFeatureStore:
             feature_definitions=feature_definitions,
         )
 
-        # Set value of enable online store to False if dynamodb not in online store sources list
-        if (
-            "dynamodb" not in online_store_sources
-            and "redis" in online_store_sources
-            and enable_online_store
-        ):
-            enable_online_store_aws = False
-
         # Feature group creation
         feature_group.create(
             s3_uri=(
@@ -275,7 +267,7 @@ class SagemakerFeatureStore:
             record_identifier_name=record_identifier_feature_name,
             event_time_feature_name=event_time_feature_name,
             role_arn=self.role,
-            enable_online_store=enable_online_store_aws,
+            enable_online_store=enable_online_store,
         )
 
         print(f'Creating "{feature_group_name}" Feature Group..')
@@ -294,7 +286,7 @@ class SagemakerFeatureStore:
             "event_time_feature_name": event_time_feature_name,
             "enable_online_store": enable_online_store,
             "online_store_sources": [source.lower() for source in online_store_sources],
-            "enable_offline_store": enable_online_store,
+            "enable_offline_store": enable_offline_store,
             "s3_uri_offline_store_output": s3_uri_offline_store_output,
             "feature_registry_path": feature_registry_s3,
         }
@@ -365,8 +357,15 @@ class SagemakerFeatureStore:
             ).delete()
 
             # remove keys from redis (ignored if not existing or expired)
-            for key in self.redis_client.scan_iter(f"{feature_group_name}:*"):
-                self.redis_client.delete(key)
+            print("Removing Feature Group in Redis..")
+            cursor = "0"
+            while cursor != 0:
+                cursor, keys = self.redis_client.scan(
+                    cursor=cursor, match=f"{feature_group_name}:*", count=3200
+                )
+                if keys:
+                    self.redis_client.delete(*keys)
+            print(f"Successfully removed {feature_group_name} Feature Group!")
         except Exception as err:
             raise Exception("ERROR - Delete Feature Group:", err)
 
@@ -553,7 +552,12 @@ class SagemakerFeatureStore:
         """
 
         def ingest_parallelize_spark_df_multithread(
-            feature_group_name, rows, record_identifier, redis_config, thread_num=10
+            feature_group_name,
+            rows,
+            record_identifier,
+            redis_config,
+            ingest_to_aws,
+            thread_num=10,
         ):
             if redis_config:
                 redis_client = Redis(
@@ -579,16 +583,17 @@ class SagemakerFeatureStore:
                     ops = 0
                     pipe = redis_client.pipeline()
                 for row in rows:
-                    # Ingest to DynamoDB online store
-                    record = [
-                        {"FeatureName": column, "ValueAsString": str(row[column])}
-                        for column in row.__fields__
-                    ]
-                    resp = runtime.put_record(
-                        FeatureGroupName=feature_group_name, Record=record
-                    )
-                    if not resp["ResponseMetadata"]["HTTPStatusCode"] == 200:
-                        raise (f"PutRecord failed: {resp}")
+                    # Ingest to AWS Sagemaker FS
+                    if ingest_to_aws:
+                        record = [
+                            {"FeatureName": column, "ValueAsString": str(row[column])}
+                            for column in row.__fields__
+                        ]
+                        resp = runtime.put_record(
+                            FeatureGroupName=feature_group_name, Record=record
+                        )
+                        if not resp["ResponseMetadata"]["HTTPStatusCode"] == 200:
+                            raise (f"PutRecord failed: {resp}")
 
                     # Ingest to Redis online store
                     if is_redis:
@@ -633,6 +638,7 @@ class SagemakerFeatureStore:
             _, fg_config = self.get_feature_group(feature_group_name)
             record_identifier = fg_config["record_identifier_feature_name"]
             online_stores = fg_config["online_store_sources"]
+            offline_store_enabled = fg_config["enable_offline_store"]
 
             if "redis" in online_stores:
                 # Initialize Redis
@@ -644,12 +650,18 @@ class SagemakerFeatureStore:
             else:
                 redis_config = None
 
+            if "dynamodb" in online_stores or offline_store_enabled:
+                ingest_to_aws = True
+            else:
+                ingest_to_aws = False
+
             paritioned_spark_df.foreachPartition(
                 lambda rows: ingest_parallelize_spark_df_multithread(
                     feature_group_name,
                     rows,
                     record_identifier,
                     redis_config,
+                    ingest_to_aws,
                     thread_num,
                 )
             )
@@ -770,7 +782,7 @@ class SagemakerFeatureStore:
         else:
             return athena_query_instance
 
-    def describe_feature_group(self, feature_group_name: str, features=None):
+    def describe_feature_group(self, feature_group_name: str):
         """
         Gets the information about a specific feature group.
 
@@ -779,35 +791,18 @@ class SagemakerFeatureStore:
         feature_group_name : str, required
             Name of the feature group to be described
 
-        features : list, not required
-            Feature keys that will be shown
-                Default : FeatureGroupName, FeatureDefinitions, FeatureGroupStatus, EventTimeFeatureName, OfflineStoreConfig, OnlineStoreConfig, RecordIdentifierFeatureName
-
         Example ::
-            ("customers-feature-group-16-07-38-24", ['FeatureGroupName', 'FeatureDefinitions'])
+            ("customers-feature-group-16-07-38-24")
 
         Returns
         -------
         JSON object
         """
-        if features is None:
-            features = [
-                "FeatureGroupName",
-                "FeatureDefinitions",
-                "FeatureGroupStatus",
-                "EventTimeFeatureName",
-                "OfflineStoreConfig",
-                "OnlineStoreConfig",
-                "RecordIdentifierFeatureName",
-            ]
 
         print("\nFEATURE GROUP:", feature_group_name)
         feature_group, fg_config = self.get_feature_group(feature_group_name)
-        custom_feature = {
-            feature_key: feature_group.describe()[feature_key]
-            for feature_key in features
-        }
-        print("\nDESCRIPTION:\n", json.dumps(custom_feature, indent=2, default=str))
+        fg_details = feature_group.describe()
+        print("\nDESCRIPTION:\n", json.dumps(fg_details, indent=2, default=str))
         print("\nCONFIGURATION:\n", json.dumps(fg_config, indent=2, default=str))
 
     def get_feature_groups_list(self):
@@ -975,7 +970,7 @@ class SagemakerFeatureStore:
             try:
                 status = feature_group.describe().get("FeatureGroupStatus")
             except Exception:
-                print(f"FeatureGroup {feature_group.name} successfully deleted.")
+                print(f"FeatureGroup {feature_group.name} successfully deleted in AWS.")
                 break
         if status == "DeleteFailed":
             raise RuntimeError(f"Failed to delete feature group {feature_group.name}")
